Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1732)

Unified Diff: pkg/analyzer/lib/src/summary/summarize_const_expr.dart

Issue 1619913005: Rename TypeRef to EntityRef. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/summary/summarize_const_expr.dart
diff --git a/pkg/analyzer/lib/src/summary/summarize_const_expr.dart b/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
index 49c4dc0b91ec2928d978ad745ec34468a0210dd8..8f3fe3a911d4b3b50880013653f3825ad345bcc3 100644
--- a/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
+++ b/pkg/analyzer/lib/src/summary/summarize_const_expr.dart
@@ -36,7 +36,7 @@ abstract class AbstractConstExprSerializer {
/**
* See [UnlinkedConstBuilder.references].
*/
- final List<TypeRefBuilder> references = <TypeRefBuilder>[];
+ final List<EntityRefBuilder> references = <EntityRefBuilder>[];
/**
* Serialize the given [expr] expression into this serializer state.
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
}
/**
* Return [TypeRefBuilder] that corresponds to the given [identifier].
*/
- TypeRefBuilder serializeIdentifier(Identifier identifier);
+ EntityRefBuilder serializeIdentifier(Identifier identifier);
/**
* Return [TypeRefBuilder] that corresponds to the given [type].
*/
- TypeRefBuilder serializeType(TypeName type);
+ EntityRefBuilder serializeType(TypeName type);
/**
* Return the [UnlinkedConstBuilder] that corresponds to the state of this
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
}
/**
- * Return [TypeRefBuilder] that corresponds to the given [identifier].
+ * Return [EntityRefBuilder] that corresponds to the given [identifier].
*/
@@ -103,14 +103,14 @@ abstract class AbstractConstExprSerializer {
/**
- * Return [TypeRefBuilder] that corresponds to the given [type].
+ * Return [EntityRefBuilder] that corresponds to the given [type].
*/

Powered by Google App Engine
This is Rietveld 408576698